Name:           ocaml-atd
Version:        2.2.1
Release:        %mkrel 2
Summary:        ATD is a syntax for defining cross-language data types
License:        BSD
Group:          Development/OCaml
URL:            https://atd.readthedocs.io/
Source0:        https://github.com/mjambon/atd/archive/%{version}/atd-%{version}.tar.gz
#Project:       https://github.com/mjambon/atd
Conflicts:      ocaml-atdgen < 2.2.1-2
BuildRequires:  ocaml-findlib-devel
BuildRequires:  ocaml-easy-format-devel
BuildRequires:  ocaml-biniou-devel
BuildRequires:  ocaml-re-devel
BuildRequires:  ocaml-sexplib0-devel
BuildRequires:  ocaml-yojson-devel
BuildRequires:  ocaml-menhir
BuildRequires:  camlmix
BuildRequires:  ocaml-dune
BuildRequires:  opam

%description
ATD stands for Adaptable Type Definitions. It is a syntax for defining
cross-language data types.

The main novelty is that this single aspect of data exchange is treated
independently from the problems of transport protocols and serialization
format. The language is properly documented and supports sum types,
parametrized types and inheritance. Any specific programming language or
data format can be accomodated using semi-structured annotations that
complete the canonical type definitions.

%package        devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}
Conflicts:      ocaml-atdgen-devel < 2.2.1-2

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%package -n     ocaml-atdgen
Summary:        Produce OCaml code from type definitions in the ATD syntax
Group:          Development/OCaml

%description -n ocaml-atdgen
Atdgen is a command-line program that takes as input type definitions in
the ATD (https://github.com/mjambon/atd) syntax and produces OCaml code
suitable for data serialization and deserialization.

Two data formats are currently supported for serialization, these are JSON
and Biniou, a binary format which retains most of JSON's properties. Atdgen
can also generate data validators derived from annotated type definitions
(starting with Atdgen 1.2.0).

Atdgen was designed with efficiency and durability in mind. Software
authors are encouraged to use Atdgen directly and to write tools that may
reuse part of Atdgen's source code.

%package -n     ocaml-atdgen-devel
Summary:        Development files for ocaml-atdgen
Group:          Development/OCaml
Requires:       ocaml-atdgen = %{version}-%{release}
Requires:       %{name}-devel = %{version}-%{release}

%description -n ocaml-atdgen-devel
The ocaml-atdgen-devel package contains libraries and signature files for
developing applications that use ocaml-atdgen.

%prep
%setup -q -n atd-%{version}

%build
dune upgrade
sed -i 's!jbuilder!dune!' Makefile
make all

%install
export DESTDIR=%{buildroot}%{_prefix}
export OCAMLFIND_DESTDIR=%{buildroot}%{_libdir}/ocaml
#mkdir -p $OCAMLFIND_DESTDIR/atd
mkdir -p %{buildroot}%{_bindir}
dune install --prefix=$DESTDIR --libdir=$OCAMLFIND_DESTDIR

# fix broken "dune install":
mv  %{buildroot}%{_prefix}%_topdir/BUILDROOT/*/*/* %{buildroot}%{_prefix}

# These files will be installed using the doc and license directives
rm -rf %{buildroot}%{_prefix}/doc

# Makes *.cmxs executable such that they will be stripped.
find %{buildroot} -name '*.cmxs' -exec chmod 0755 {} \;


%files
%doc README.md CHANGES.md
%{_bindir}/atdcat
%{_bindir}/atdj
%{_bindir}/atds
%dir %{_libdir}/ocaml/atd
%{_libdir}/ocaml/atd/META
%{_libdir}/ocaml/atd/opam
%{_libdir}/ocaml/atd/*dune*
%{_libdir}/ocaml/atd/*.cma
%{_libdir}/ocaml/atd/*.cmi
%{_libdir}/ocaml/atd/*.cmxs

%dir %{_libdir}/ocaml/atdj
%{_libdir}/ocaml/atdj/META
%{_libdir}/ocaml/atdj/opam
%{_libdir}/ocaml/atdj/*dune*

%dir %{_libdir}/ocaml/atds
%{_libdir}/ocaml/atds/META
%{_libdir}/ocaml/atds/opam
%{_libdir}/ocaml/atds/*dune*

%files devel
%doc manual/
%{_libdir}/ocaml/atd/*.a
%{_libdir}/ocaml/atd/*.cmt
%{_libdir}/ocaml/atd*/*.cmti
%{_libdir}/ocaml/atd/*.cmxa
%{_libdir}/ocaml/atd/*.cmx
%{_libdir}/ocaml/atd*/*.mli
%{_libdir}/ocaml/atd/*.ml

%files -n ocaml-atdgen
%doc atdgen/README.md
%{_bindir}/atdgen
%{_bindir}/atdgen-cppo
%{_bindir}/cppo-json
%dir %{_libdir}/ocaml/atd*/
%{_libdir}/ocaml/atdgen*/META
%{_libdir}/ocaml/atdgen*/opam
%{_libdir}/ocaml/atdgen*/*dune*
%{_libdir}/ocaml/atdgen*/*.cma
%{_libdir}/ocaml/atdgen*/*.cmi
%{_libdir}/ocaml/atdgen*/*.cmxs

%files -n ocaml-atdgen-devel
%doc manual/
%doc atdgen/example/
%{_libdir}/ocaml/atdgen*/*.a
%{_libdir}/ocaml/atdgen*/*.cmt
%{_libdir}/ocaml/atdgen*/*.cmxa
%{_libdir}/ocaml/atdgen*/*.cmx
%{_libdir}/ocaml/atdgen*/*.ml


%changelog
* Tue Feb 02 2021 pterjan <pterjan> 2.2.1-2.mga8
+ Revision: 1674510
- Fix file lists

* Mon Aug 24 2020 tv <tv> 2.2.1-1.mga8
+ Revision: 1618339
- 2.2.1 (thus fixing build)

* Fri Feb 28 2020 umeabot <umeabot> 2.1.0-3.mga8
+ Revision: 1551740
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 2.1.0-2.mga8
+ Revision: 1543730
- Mageia 8 Mass Rebuild

* Wed Jan 22 2020 tv <tv> 2.1.0-1.mga8
+ Revision: 1482180
- new release + rebuild for ocaml-4.10

* Thu Oct 25 2018 daviddavid <daviddavid> 2.0.0-2.mga7
+ Revision: 1325192
- rebuild for new ocaml 4.07.1

* Mon Aug 27 2018 daviddavid <daviddavid> 2.0.0-1.mga7
+ Revision: 1254840
- new version: 2.0.0
- ocaml-atdgen is now part of the ocaml-atd source pkg
- switch to jbuilder

* Tue Jun 26 2018 daviddavid <daviddavid> 1.1.2-7.mga7
+ Revision: 1239755
- rebuild for new ocaml-easy-format 1.3.1

* Sun Nov 26 2017 tv <tv> 1.1.2-6.mga7
+ Revision: 1179473
- rebuild for new ocaml

* Thu Oct 12 2017 daviddavid <daviddavid> 1.1.2-5.mga7
+ Revision: 1171364
- rebuild for fixed ocaml (use standard ISO C99 types {u}uint{32,64}_t)

* Wed Feb 17 2016 umeabot <umeabot> 1.1.2-4.mga6
+ Revision: 963942
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.1.2-3.mga5
+ Revision: 740483
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.1.2-2.mga5
+ Revision: 682984
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 malo <malo> 1.1.2-1.mga5
+ Revision: 674063
- update to 1.1.2

* Sat Oct 19 2013 umeabot <umeabot> 1.0.3-3.mga4
+ Revision: 536417
- Mageia 4 Mass Rebuild

* Mon Sep 23 2013 blue_prawn <blue_prawn> 1.0.3-2.mga4
+ Revision: 484248
- rebuild for ocaml-4.01.0

* Sun Jun 09 2013 malo <malo> 1.0.3-1.mga4
+ Revision: 441331
- remove some of the doc
- update to 1.03
- fix URL

* Sat Jan 12 2013 umeabot <umeabot> 1.0.1-5.mga3
+ Revision: 361145
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Dec 04 2012 malo <malo> 1.0.1-4.mga3
+ Revision: 326531
- rebuild for new ocaml

* Tue Oct 02 2012 blue_prawn <blue_prawn> 1.0.1-3.mga3
+ Revision: 302183
- rebuild for new ocaml 4.00

* Sat Sep 29 2012 blue_prawn <blue_prawn> 1.0.1-2.mga3
+ Revision: 300032
- new rpm group for ocaml

* Sun Jun 24 2012 blue_prawn <blue_prawn> 1.0.1-1.mga3
+ Revision: 263099
- needs menhir to compile
- imported package ocaml-atd

